"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initReporters = void 0;
const Logger_1 = require("./Logger");
const NpmLogReporter_1 = require("./reporters/NpmLogReporter");
const LogLevel_1 = require("./LogLevel");
const JsonReporter_1 = require("./reporters/JsonReporter");
const AdoReporter_1 = require("./reporters/AdoReporter");
const DgmlReporter_1 = require("./reporters/DgmlReporter");
const CustomReporter_1 = require("./reporters/CustomReporter");
function initReporters(config) {
    // Initialize logger
    let logLevel = config.verbose ? LogLevel_1.LogLevel.verbose : LogLevel_1.LogLevel.info;
    if (config.logLevel) {
        logLevel = LogLevel_1.LogLevel[config.logLevel];
    }
    let reporters = [];
    if (config.reporter.includes("json")) {
        reporters.push(new JsonReporter_1.JsonReporter({ logLevel }));
    }
    else if (config.reporter.includes("dgml")) {
        reporters.push(new DgmlReporter_1.DgmlReporter());
    }
    else {
        reporters.push(new NpmLogReporter_1.NpmLogReporter({ logLevel, grouped: config.grouped, npmLoggerOptions: config.loggerOptions }));
    }
    // Will always include NpmLogReporter and add AdoReporter
    if (config.reporter.includes("adoLog")) {
        reporters.push(new AdoReporter_1.AdoReporter());
    }
    // Will always include CustomReporter as well to pass metadata.
    const configReporters = Array.from(config.reporter);
    for (const reporter of configReporters) {
        if (reporter.match(/\.[jt]s$/)) {
            reporters.push(new CustomReporter_1.CustomReporter(reporter));
        }
    }
    Logger_1.Logger.reporters = reporters;
    return reporters;
}
exports.initReporters = initReporters;
//# sourceMappingURL=initReporters.js.map